@@ -278,8 +278,7 @@ class WBPaper(object):
         Returns:
             bool: whether the paper has a temporary pdf file
         """
-        return self.main_text is None and self.html_text is None and self.ocr_text is None \
-            and self.aut_text is None and self.temp_text is None
+        return not (self.main_text or self.html_text or self.ocr_text or self.aut_text or self.temp_text)
 
     def has_supplementary_material(self):
         """determine if the paper has supplemental material associated to it
@@ -290,8 +289,8 @@ class WBPaper(object):
         return self.supplemental_docs
 
     def has_main_text(self):
-        return self.main_text is not None or self.html_text is not None or self.ocr_text is not None or self.aut_text \
-               is not None or self.temp_text is not None or self.proof_text is not None
+        return self.main_text != '' or self.html_text != '' or self.ocr_text != '' or self.aut_text != '' or \
+               self.temp_text != '' or self.proof_text != ''
 
     def extract_all_email_addresses_from_text(self, text: str = None):
         """get all the email addresses mentioned in any of the documents associated with this paper"""
